@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include "pgmodelerapp.h"
 #include "mainwindow.h"
+#include <QSplashScreen>
 
 #ifndef Q_OS_WIN
 #include "execinfo.h"
@@ -38,7 +39,7 @@ void startCrashHandler(int signal)
 	symbols = backtrace_symbols(stack, stack_size);
 #endif
 
-	cmd=QString("\"%1\"").arg(GlobalAttributes::getPgModelerCHandlerPath()) + QString(" -style ") + GlobalAttributes::DefaultQtStyle;
+	cmd=QString("\"%1\"").arg(GlobalAttributes::getPgModelerCHandlerPath()) + " -style " + GlobalAttributes::DefaultQtStyle;
 
 	//Creates the stacktrace file
 	output.setFileName(GlobalAttributes::getTemporaryFilePath(GlobalAttributes::StacktraceFile));
@@ -48,7 +49,7 @@ void startCrashHandler(int signal)
 	{
 		lin=QString("** pgModeler crashed after receive signal: %1 **\n\nDate/Time: %2 \nVersion: %3 \nBuild: %4 \n")
 			.arg(signal)
-			.arg(QDateTime::currentDateTime().toString(QString("yyyy-MM-dd hh:mm:ss")))
+			.arg(QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss"))
 			.arg(GlobalAttributes::PgModelerVersion)
 			.arg(GlobalAttributes::PgModelerBuildNumber);
 
@@ -61,12 +62,12 @@ void startCrashHandler(int signal)
 #ifndef Q_OS_WIN
 		for(size_t i=0; i < stack_size; i++)
 		{
-			lin=QString("[%1] ").arg(stack_size-1-i) + QString(symbols[i]) + QString("\n");
+			lin=QString("[%1] ").arg(stack_size-1-i) + QString(symbols[i]) + "\n";
 			output.write(lin.toStdString().c_str(), lin.size());
 		}
 		free(symbols);
 #else
-		lin=QString("** Stack trace unavailable on Windows system **");
+		lin = "** Stack trace unavailable on Windows system **";
 		output.write(lin.toStdString().c_str(), lin.size());
 #endif
 
@@ -81,6 +82,8 @@ void startCrashHandler(int signal)
 	exit(1 + system(cmd.toStdString().c_str()));
 }
 
+
+
 int main(int argc, char **argv)
 {
 	try
@@ -89,7 +92,7 @@ int main(int argc, char **argv)
 		signal(SIGSEGV, startCrashHandler);
 		signal(SIGABRT, startCrashHandler);
 
-		GlobalAttributes::setCustomUiScaleFactor();
+		GlobalAttributes::init(argv[0], true);
 		PgModelerApp app(argc,argv);
 		int res=0;
 
