@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 #include "basegraphicobject.h"
 
-bool BaseGraphicObject::updates_enabled = true;
+bool BaseGraphicObject::updates_enabled { true };
 
 BaseGraphicObject::BaseGraphicObject()
 {
@@ -56,12 +56,7 @@ void BaseGraphicObject::setModified(bool value)
 
 void BaseGraphicObject::setSQLDisabled(bool value)
 {
-	//bool curr_val=sql_disabled;
-
 	BaseObject::setSQLDisabled(value);
-
-	//if(value != curr_val && updates_enabled)
-	//	emit s_objectModified();
 }
 
 void BaseGraphicObject::setFadedOut(bool value)
