@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,19 +25,15 @@
 #ifndef BASE_OBJECT_WIDGET_H
 #define BASE_OBJECT_WIDGET_H
 
-#include <QtWidgets>
 #include "databasemodel.h"
 #include "operationlist.h"
-#include "widgets/modelobjectswidget.h"
 #include "widgets/objectselectorwidget.h"
 #include "ui_baseobjectwidget.h"
-#include "pgsqltypewidget.h"
-#include "guiutilsns.h"
+#include "qtconnectmacros.h"
 
 class __libgui BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
 	protected:
 		static constexpr int MaxObjectSize=16777215;
 
@@ -95,6 +91,11 @@ class __libgui BaseObjectWidget: public QWidget, public Ui::BaseObjectWidget {
 			The obj_type parameter must be specified to show the object type icon */
 		void configureFormLayout(QGridLayout *grid=nullptr, ObjectType obj_type=ObjectType::BaseObject);
 		
+		/*! \brief Configures the state of commom fields related to database objects enabling/disabling/hidding
+		 * according to the object type. The parameter inst_ev_filter indicates if the special event filter
+		 * must be installed on input fields. The event filter calls applyConfiguration() when ENTER/RETURN is pressed */
+		void configureFormFields(ObjectType obj_type, bool inst_ev_filter = true);
+
 		/*! \brief Starts a object configuration, alocating a new one if necessary, registering
 			the object on the operation list. This method doens't applies to database model edition */
 		template<class Class>
