@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,31 +26,39 @@
 #define LAYERS_WIDGET_H
 
 #include "guiglobal.h"
-#include <QWidget>
 #include "ui_layerswidget.h"
 #include "basegraphicobject.h"
 
-class __libgui LayersWidget : public QWidget, Ui::LayersWidget {
-	private:
-		Q_OBJECT
+class ModelWidget;
 
+class __libgui LayersWidget : public QDialog, Ui::LayersWidget {
+	Q_OBJECT
+
+	private:
 		//! \brief The current object selection in a model widget that the layer widget will operate on.
 		std::vector<BaseGraphicObject *> selected_objs;
 
 		//! \brief Indicates if the user have interacted with the layers checkboxes changing objects layers.
 		bool layers_changed;
 
+		bool eventFilter(QObject *object, QEvent *event) override;
+
 	public:
 		explicit LayersWidget(QWidget *parent = nullptr);
 
-		//! \brief Configures the widget with layer names and a set of object selected in a model widget
-		void setAttributes(const QStringList &layers, const std::vector<BaseObject *> &selected_objs);
+		//! \brief Configures the widget with layer names and a set of object selected in a model widget instance
+		void setAttributes(ModelWidget *model_wgt);
 
 		//! \brief Returns true if the layers of the selected object have been changed by the user.
 		bool isLayersChanged();
 
 	private slots:
 		void updateObjectsLayers();
+
+	signals:
+		void s_newLayerRequested(const QString &layer_name);
+
+		void s_objectsLayerChanged();
 };
 
 #endif
